@@ -16,12 +16,14 @@ class WordPressReader(object):
             internal_cms_link_prefix,
             content_path_prefix,
             port=3306,
+            connect_timeout=30,
             table_prefix='wp'):
         self.host = host
         self.port = port
         self.user = user
         self.passwd = passwd
         self.db = db
+        self.connect_timeout = connect_timeout
         self.table_prefix = table_prefix
         self.internal_cms_link_prefix = internal_cms_link_prefix
         self.content_path_prefix = content_path_prefix
@@ -33,6 +35,7 @@ class WordPressReader(object):
             port=self.port,
             user=self.user,
             passwd=self.passwd,
+            connect_timeout=self.connect_timeout,
             db=self.db)
 
     @property
